@@ -1,4 +1,4 @@
-//@line 42 "/mnt/Thunderbird/build/mail/components/addrbook/content/addressbook.js"
+//@line 42 "/home/karma/src/build/mail/components/addrbook/content/addressbook.js"
 
 // Ensure the activity modules are loaded for this window.
 Components.utils.import("resource://app/modules/activity/activityModules.js");
@@ -16,6 +16,9 @@ var gCardViewBox;
 var gCardViewBoxEmail1;
 var gPreviousDirTreeIndex = -1;
 
+var msgWindow = Components.classes["@mozilla.org/messenger/msgwindow;1"]
+                          .createInstance(Components.interfaces.nsIMsgWindow);
+
 // Constants that correspond to choices
 // in Address Book->View -->Show Name as
 const kDisplayName = 0;
@@ -86,6 +89,10 @@ function OnUnloadAddressBook()
             .getService(Components.interfaces.nsIAbManager)
             .removeAddressBookListener(gAddressBookAbListener);
 
+  Components.classes["@mozilla.org/messenger/services/session;1"]
+            .getService(Components.interfaces.nsIMsgMailSession)
+            .RemoveMsgWindow(msgWindow);
+
   CloseAbView();
 }
 
@@ -175,6 +182,10 @@ function delayedOnLoadAddressBook()
         .getInterface(Components.interfaces.nsIWebNavigation)
         .QueryInterface(Components.interfaces.nsIDocShell)
         .useErrorPages = false;
+
+  Components.classes["@mozilla.org/messenger/services/session;1"]
+            .getService(Components.interfaces.nsIMsgMailSession)
+            .AddMsgWindow(msgWindow);
 }
 
 function OnLoadDirTree() {
